---
title: "Introduction"
description: "Welcome to FlashInfer-Bench, the AI-for-AI infrastructure that makes LLM serving self-improving."
---

## Try it out

Evaluate your kernel implementation using FlashInfer-Bench in minutes.

<Card
  title="Start here"
  icon="rocket"
  href="/start/quickstart"
  horizontal
>
  Follow our quickstart guide.
</Card>

## Concepts

Key components of FlashInfer-Bench.

<Columns cols={2}>
  <Card
    title="FlashInfer Trace"
    icon="brackets-curly"
    href="/flashinfer-trace"
  >
    The standard schema for defining and benchmarking kernels. Learn about how we integrate fastest kernels into production on day-0.
  </Card>
  <Card
    title="Bring your own kernel"
    icon="puzzle-piece"
    href="/tutorials/bring-your-own-kernel"
  >
    How to integrate your kernel into FlashInfer-Bench.
  </Card>
  <Card
    title="Op Types"
    icon="layer-group"
    href="/op-types/gemm"
  >
    Check out the list of our supported op types.
  </Card>
  <Card
    title="Read the blog post"
    icon="stars"
    href="https://flashinfer.ai/2025/10/21/flashinfer-bench.html"
  >
    Get to know more about our vision and design choices.
  </Card>
</Columns>
